@@ -1,18 +1,23 @@
 """ACMPCABackend class with methods for supported APIs."""
+
 import base64
-from .exceptions import ResourceNotFoundException
-from moto.core import BaseBackend, BackendDict, BaseModel
+import datetime
+from typing import Any, Dict, List, Optional, Tuple
+
+import cryptography.hazmat.primitives.asymmetric.rsa
+import cryptography.x509
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives import hashes, serialization
+from cryptography.x509 import Certificate, NameOID, load_pem_x509_certificate
+
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel
 from moto.core.utils import unix_time, utcnow
 from moto.moto_api._internal import mock_random
 from moto.utilities.tagging_service import TaggingService
+from moto.utilities.utils import get_partition
 
-import datetime
-import cryptography.x509
-from cryptography.x509 import NameOID, load_pem_x509_certificate, Certificate
-import cryptography.hazmat.primitives.asymmetric.rsa
-from cryptography.hazmat.primitives import serialization, hashes
-from cryptography.hazmat.backends import default_backend
-from typing import Any, Dict, List, Optional, Tuple
+from .exceptions import InvalidS3ObjectAclInCrlConfiguration, ResourceNotFoundException
 
 
 class CertificateAuthority(BaseModel):
@@ -26,9 +31,7 @@ class CertificateAuthority(BaseModel):
         security_standard: Optional[str],
     ):
         self.id = mock_random.uuid4()
-        self.arn = (
-            f"arn:aws:acm-pca:{region}:{account_id}:certificate-authority/{self.id}"
-        )
+        self.arn = f"arn:{get_partition(region)}:acm-pca:{region}:{account_id}:certificate-authority/{self.id}"
         self.account_id = account_id
         self.region_name = region
         self.certificate_authority_configuration = certificate_authority_configuration
@@ -43,9 +46,9 @@ class CertificateAuthority(BaseModel):
         self.usage_mode = "SHORT_LIVED_CERTIFICATE"
         self.security_standard = security_standard or "FIPS_140_2_LEVEL_3_OR_HIGHER"
 
-        common_name = self.certificate_authority_configuration.get("Subject", {}).get(
-            "CommonName", "Moto.org"
-        )
+        self.common_name = self.certificate_authority_configuration.get(
+            "Subject", {}
+        ).get("CommonName", "Moto.org")
         self.key = cryptography.hazmat.primitives.asymmetric.rsa.generate_private_key(
             public_exponent=65537, key_size=2048
         )
@@ -57,7 +60,7 @@ class CertificateAuthority(BaseModel):
         )
         self.certificate: Optional[Certificate] = None
         self.certificate_chain: Optional[bytes] = None
-        self.csr = self.generate_csr(common_name)
+        self.csr = self.generate_csr(self.common_name)
 
         self.issued_certificates: Dict[str, bytes] = dict()
 
@@ -113,9 +116,11 @@ class CertificateAuthority(BaseModel):
 
     def issue_certificate(self, csr_bytes: bytes) -> str:
         cert = cryptography.x509.load_pem_x509_csr(base64.b64decode(csr_bytes))
-        new_cert = self.generate_cert(common_name="", subject=cert.subject)
+        new_cert = self.generate_cert(
+            common_name=self.common_name, subject=cert.subject
+        )
         cert_id = str(mock_random.uuid4()).replace("-", "")
-        cert_arn = f"arn:aws:acm-pca:{self.region_name}:{self.account_id}:certificate-authority/{self.id}/certificate/{cert_id}"
+        cert_arn = f"arn:{get_partition(self.region_name)}:acm-pca:{self.region_name}:{self.account_id}:certificate-authority/{self.id}/certificate/{cert_id}"
         self.issued_certificates[cert_arn] = new_cert
         return cert_arn
 
@@ -128,13 +133,16 @@ class CertificateAuthority(BaseModel):
         if revocation_configuration is not None:
             self.revocation_configuration = revocation_configuration
             if "CrlConfiguration" in self.revocation_configuration:
-                if (
-                    "S3ObjectAcl"
-                    not in self.revocation_configuration["CrlConfiguration"]
-                ):
-                    self.revocation_configuration["CrlConfiguration"][
-                        "S3ObjectAcl"
-                    ] = "PUBLIC_READ"
+                acl = self.revocation_configuration["CrlConfiguration"].get(
+                    "S3ObjectAcl", None
+                )
+                if acl is None:
+                    self.revocation_configuration["CrlConfiguration"]["S3ObjectAcl"] = (
+                        "PUBLIC_READ"
+                    )
+                else:
+                    if acl not in ["PUBLIC_READ", "BUCKET_OWNER_FULL_CONTROL"]:
+                        raise InvalidS3ObjectAclInCrlConfiguration(acl)
 
     @property
     def certificate_bytes(self) -> bytes:
@@ -146,13 +154,19 @@ class CertificateAuthority(BaseModel):
     def not_valid_after(self) -> Optional[float]:
         if self.certificate is None:
             return None
-        return unix_time(self.certificate.not_valid_after)
+        try:
+            return unix_time(self.certificate.not_valid_after_utc.replace(tzinfo=None))
+        except AttributeError:
+            return unix_time(self.certificate.not_valid_after)
 
     @property
     def not_valid_before(self) -> Optional[float]:
         if self.certificate is None:
             return None
-        return unix_time(self.certificate.not_valid_before)
+        try:
+            return unix_time(self.certificate.not_valid_before_utc.replace(tzinfo=None))
+        except AttributeError:
+            return unix_time(self.certificate.not_valid_before)
 
     def import_certificate_authority_certificate(
         self, certificate: bytes, certificate_chain: Optional[bytes]
