@@ -7,7 +7,8 @@ import yaml
 from yaml.parser import ParserError  # pylint:disable=c-extension-no-member
 from yaml.scanner import ScannerError  # pylint:disable=c-extension-no-member
 
-from moto.core import BackendDict, BaseBackend, BaseModel, CloudFormationModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel, CloudFormationModel
 from moto.core.utils import (
     iso_8601_datetime_with_milliseconds,
     iso_8601_datetime_without_milliseconds,
@@ -16,6 +17,7 @@ from moto.core.utils import (
 from moto.moto_api._internal import mock_random
 from moto.organizations.models import OrganizationsBackend, organizations_backends
 from moto.sns.models import sns_backends
+from moto.utilities.utils import get_partition
 
 from .custom_model import CustomModel
 from .exceptions import StackSetNotEmpty, StackSetNotFoundException, ValidationError
@@ -53,12 +55,19 @@ class FakeStackSet(BaseModel):
         self.description = description
         self.parameters = parameters
         self.tags = tags
-        self.admin_role = admin_role
-        self.admin_role_arn = f"arn:aws:iam::{account_id}:role/{self.admin_role}"
+        self.admin_role = (
+            admin_role
+            or f"arn:{get_partition(region)}:iam::{account_id}:role/AWSCloudFormationStackSetAdministrationRole"
+        )
         self.execution_role = execution_role or "AWSCloudFormationStackSetExecutionRole"
         self.status = "ACTIVE"
         self.instances = FakeStackInstances(
-            account_id, template, parameters, self.id, self.name
+            account_id=account_id,
+            region=region,
+            template=template,
+            parameters=parameters,
+            stackset_id=self.id,
+            stackset_name=self.name,
         )
         self.stack_instances = self.instances.stack_instances
         self.operations: List[Dict[str, Any]] = []
@@ -116,7 +125,6 @@ class FakeStackSet(BaseModel):
         regions: List[str],
         operation_id: str,
     ) -> Dict[str, Any]:
-
         self.template = template or self.template
         self.description = description if description is not None else self.description
         self.parameters = parameters or self.parameters
@@ -281,12 +289,14 @@ class FakeStackInstances(BaseModel):
     def __init__(
         self,
         account_id: str,
+        region: str,
         template: str,
         parameters: Dict[str, str],
         stackset_id: str,
         stackset_name: str,
     ):
         self.account_id = account_id
+        self.partition = get_partition(region)
         self.template = template
         self.parameters = parameters or {}
         self.stackset_id = stackset_id
@@ -296,7 +306,7 @@ class FakeStackInstances(BaseModel):
 
     @property
     def org_backend(self) -> OrganizationsBackend:
-        return organizations_backends[self.account_id]["global"]
+        return organizations_backends[self.account_id][self.partition]
 
     def create_instances(
         self,
@@ -384,11 +394,12 @@ class FakeStack(CloudFormationModel):
         self.name = name
         self.account_id = account_id
         self.template = template
+        self.template_dict: Dict[str, Any]
         if template != {}:
             self._parse_template()
             self.description = self.template_dict.get("Description")
         else:
-            self.template_dict: Dict[str, Any] = {}
+            self.template_dict = {}
             self.description = None
         self.parameters = parameters
         self.region_name = region_name
@@ -412,12 +423,8 @@ class FakeStack(CloudFormationModel):
         self.status = "CREATE_PENDING"
 
     def has_template(self, other_template: str) -> bool:
-        our_template = (
-            self.template
-            if isinstance(self.template, dict)
-            else json.loads(self.template)
-        )
-        return our_template == json.loads(other_template)
+        self._parse_template()
+        return self.template_dict == self.parse_template(other_template)
 
     def has_parameters(self, other_parameters: Dict[str, Any]) -> bool:
         return self.parameters == other_parameters
@@ -441,7 +448,7 @@ class FakeStack(CloudFormationModel):
 
     @property
     def creation_time_iso_8601(self) -> str:
-        return iso_8601_datetime_without_milliseconds(self.creation_time)  # type: ignore[return-value]
+        return iso_8601_datetime_without_milliseconds(self.creation_time)
 
     def _add_stack_event(
         self,
@@ -449,7 +456,6 @@ class FakeStack(CloudFormationModel):
         resource_status_reason: Optional[str] = None,
         resource_properties: Optional[str] = None,
     ) -> None:
-
         event = FakeEvent(
             stack_id=self.stack_id,
             stack_name=self.name,
@@ -465,11 +471,15 @@ class FakeStack(CloudFormationModel):
         self.events.append(event)
 
     def _parse_template(self) -> None:
+        self.template_dict = self.parse_template(self.template)  # type: ignore[arg-type]
+
+    @staticmethod
+    def parse_template(template: str) -> Dict[str, Any]:  # type: ignore[misc]
         yaml.add_multi_constructor("", yaml_tag_constructor)
         try:
-            self.template_dict = yaml.load(self.template, Loader=yaml.Loader)  # type: ignore[arg-type]
+            return yaml.load(template, Loader=yaml.Loader)
         except (ParserError, ScannerError):
-            self.template_dict = json.loads(self.template)  # type: ignore[arg-type]
+            return json.loads(template)
 
     @property
     def stack_parameters(self) -> Dict[str, Any]:  # type: ignore[misc]
@@ -526,6 +536,8 @@ class FakeStack(CloudFormationModel):
         self._add_stack_event("UPDATE_COMPLETE")
         self.status = "UPDATE_COMPLETE"
         self.role_arn = role_arn
+        if parameters:
+            self.parameters = parameters
         # only overwrite tags if passed
         if tags is not None:
             self.tags = tags
@@ -565,7 +577,11 @@ class FakeStack(CloudFormationModel):
         ]
         properties = cloudformation_json["Properties"]
 
-        template_body = get_stack_from_s3_url(properties["TemplateURL"], account_id)
+        template_body = get_stack_from_s3_url(
+            properties["TemplateURL"],
+            account_id=account_id,
+            partition=get_partition(region_name),
+        )
         parameters = properties.get("Parameters", {})
 
         return cf_backend.create_stack(
@@ -654,7 +670,7 @@ class FakeChangeSet(BaseModel):
 
     @property
     def creation_time_iso_8601(self) -> str:
-        return iso_8601_datetime_without_milliseconds(self.creation_time)  # type: ignore[return-value]
+        return iso_8601_datetime_without_milliseconds(self.creation_time)
 
     def diff(self) -> List[FakeChange]:
         changes = []
@@ -776,7 +792,7 @@ class CloudFormationBackend(BaseBackend):
                     instance.parameters[parameter["parameter_key"]],
                 )
                 for parameter in incoming_params
-                if "use_previous_value" in parameter
+                if parameter.get("use_previous_value") == "true"
             ]
         )
         parameters.update(previous)
