@@ -1,24 +1,24 @@
 import copy
-import json
-
 import itertools
+import json
 from functools import wraps
-from typing import Any, Dict, List, Union, Callable, Optional
+from typing import Any, Callable, Dict, List, Optional, Union
 
 from moto.core.common_types import TYPE_RESPONSE
 from moto.core.responses import BaseResponse
-from moto.core.utils import camelcase_to_underscores
+from moto.dynamodb.models import DynamoDBBackend, Table, dynamodb_backends
+from moto.dynamodb.models.utilities import dynamo_json_dump
+from moto.dynamodb.parsing.expressions import UpdateExpressionParser  # type: ignore
 from moto.dynamodb.parsing.key_condition_expression import parse_expression
 from moto.dynamodb.parsing.reserved_keywords import ReservedKeywords
+from moto.utilities.aws_headers import amz_crc32
+
 from .exceptions import (
+    KeyIsEmptyStringException,
     MockValidationException,
     ResourceNotFoundException,
     UnknownKeyType,
 )
-from moto.dynamodb.models import dynamodb_backends, Table, DynamoDBBackend
-from moto.dynamodb.models.utilities import dynamo_json_dump
-from moto.utilities.aws_headers import amz_crc32, amzn_request_id
-
 
 TRANSACTION_MAX_ITEMS = 25
 
@@ -30,7 +30,7 @@ def include_consumed_capacity(
     Callable[["DynamoHandler"], Union[str, TYPE_RESPONSE]],
 ]:
     def _inner(
-        f: Callable[..., Union[str, TYPE_RESPONSE]]
+        f: Callable[["DynamoHandler"], str],
     ) -> Callable[["DynamoHandler"], Union[str, TYPE_RESPONSE]]:
         @wraps(f)
         def _wrapper(
@@ -40,10 +40,12 @@ def include_consumed_capacity(
             expected_capacity = handler.body.get("ReturnConsumedCapacity", "NONE")
             if expected_capacity not in ["NONE", "TOTAL", "INDEXES"]:
                 type_ = "ValidationException"
+                headers = handler.response_headers.copy()
+                headers["status"] = "400"
                 message = f"1 validation error detected: Value '{expected_capacity}' at 'returnConsumedCapacity' failed to satisfy constraint: Member must satisfy enum value set: [INDEXES, TOTAL, NONE]"
                 return (
                     400,
-                    handler.response_headers,
+                    headers,
                     dynamo_json_dump({"__type": type_, "message": message}),
                 )
             table_name = handler.body.get("TableName", "")
@@ -189,22 +191,9 @@ class DynamoHandler(BaseResponse):
         return dynamodb_backends[self.current_account][self.region]
 
     @amz_crc32
-    @amzn_request_id
     def call_action(self) -> TYPE_RESPONSE:
         self.body = json.loads(self.body or "{}")
-        endpoint = self.get_endpoint_name(self.headers)
-        if endpoint:
-            endpoint = camelcase_to_underscores(endpoint)
-            response = getattr(self, endpoint)()
-            if isinstance(response, str):
-                return 200, self.response_headers, response
-
-            else:
-                status_code, new_headers, response_content = response
-                self.response_headers.update(new_headers)
-                return status_code, self.response_headers, response_content
-        else:
-            return 404, self.response_headers, ""
+        return super().call_action()
 
     def list_tables(self) -> str:
         body = self.body
@@ -222,105 +211,125 @@ class DynamoHandler(BaseResponse):
 
     def create_table(self) -> str:
         body = self.body
-        # get the table name
         table_name = body["TableName"]
         # check billing mode and get the throughput
         if "BillingMode" in body.keys() and body["BillingMode"] == "PAY_PER_REQUEST":
-            if "ProvisionedThroughput" in body.keys():
-                raise MockValidationException(
-                    "ProvisionedThroughput cannot be specified when BillingMode is PAY_PER_REQUEST"
-                )
-            throughput = None
             billing_mode = "PAY_PER_REQUEST"
-        else:  # Provisioned (default billing mode)
-            throughput = body.get("ProvisionedThroughput")
-            if throughput is None:
-                raise MockValidationException(
-                    "One or more parameter values were invalid: ReadCapacityUnits and WriteCapacityUnits must both be specified when BillingMode is PROVISIONED"
-                )
-            billing_mode = "PROVISIONED"
-        # getting ServerSideEncryption details
+        else:
+            billing_mode = "PROVISIONED"  # Default
+        throughput = body.get("ProvisionedThroughput")
         sse_spec = body.get("SSESpecification")
-        # getting the schema
         key_schema = body["KeySchema"]
-        for idx, _key in enumerate(key_schema, start=1):
-            key_type = _key["KeyType"]
-            if key_type not in ["HASH", "RANGE"]:
-                raise UnknownKeyType(
-                    key_type=key_type, position=f"keySchema.{idx}.member.keyType"
-                )
-        # getting attribute definition
         attr = body["AttributeDefinitions"]
-
-        # getting/validating the indexes
         global_indexes = body.get("GlobalSecondaryIndexes")
-        if global_indexes == []:
-            raise MockValidationException(
-                "One or more parameter values were invalid: List of GlobalSecondaryIndexes is empty"
-            )
-        global_indexes = global_indexes or []
-        for idx, g_idx in enumerate(global_indexes, start=1):
-            for idx2, _key in enumerate(g_idx["KeySchema"], start=1):
-                key_type = _key["KeyType"]
-                if key_type not in ["HASH", "RANGE"]:
-                    position = f"globalSecondaryIndexes.{idx}.member.keySchema.{idx2}.member.keyType"
-                    raise UnknownKeyType(key_type=key_type, position=position)
-
         local_secondary_indexes = body.get("LocalSecondaryIndexes")
-        if local_secondary_indexes == []:
-            raise MockValidationException(
-                "One or more parameter values were invalid: List of LocalSecondaryIndexes is empty"
-            )
-        local_secondary_indexes = local_secondary_indexes or []
-        for idx, g_idx in enumerate(local_secondary_indexes, start=1):
-            for idx2, _key in enumerate(g_idx["KeySchema"], start=1):
-                key_type = _key["KeyType"]
-                if key_type not in ["HASH", "RANGE"]:
-                    position = f"localSecondaryIndexes.{idx}.member.keySchema.{idx2}.member.keyType"
-                    raise UnknownKeyType(key_type=key_type, position=position)
-
-        # Verify AttributeDefinitions list all
-        expected_attrs = []
-        expected_attrs.extend([key["AttributeName"] for key in key_schema])
-        expected_attrs.extend(
-            schema["AttributeName"]
-            for schema in itertools.chain(
-                *list(idx["KeySchema"] for idx in local_secondary_indexes)
-            )
-        )
-        expected_attrs.extend(
-            schema["AttributeName"]
-            for schema in itertools.chain(
-                *list(idx["KeySchema"] for idx in global_indexes)
-            )
-        )
-        expected_attrs = list(set(expected_attrs))
-        expected_attrs.sort()
-        actual_attrs = [item["AttributeName"] for item in attr]
-        actual_attrs.sort()
-        if actual_attrs != expected_attrs:
-            self._throw_attr_error(
-                actual_attrs, expected_attrs, global_indexes or local_secondary_indexes
-            )
-        # get the stream specification
         streams = body.get("StreamSpecification")
-        # Get any tags
         tags = body.get("Tags", [])
+        deletion_protection_enabled = body.get("DeletionProtectionEnabled", False)
+
+        self._validate_table_creation(
+            billing_mode=billing_mode,
+            throughput=throughput,
+            key_schema=key_schema,
+            global_indexes=global_indexes,
+            local_secondary_indexes=local_secondary_indexes,
+            attr=attr,
+        )
 
         table = self.dynamodb_backend.create_table(
             table_name,
             schema=key_schema,
             throughput=throughput,
             attr=attr,
-            global_indexes=global_indexes,
-            indexes=local_secondary_indexes,
+            global_indexes=global_indexes or [],
+            indexes=local_secondary_indexes or [],
             streams=streams,
             billing_mode=billing_mode,
             sse_specification=sse_spec,
             tags=tags,
+            deletion_protection_enabled=deletion_protection_enabled,
         )
         return dynamo_json_dump(table.describe())
 
+    def _validate_table_creation(
+        self,
+        billing_mode: str,
+        throughput: Optional[Dict[str, Any]],
+        key_schema: List[Dict[str, str]],
+        global_indexes: Optional[List[Dict[str, Any]]],
+        local_secondary_indexes: Optional[List[Dict[str, Any]]],
+        attr: List[Dict[str, str]],
+    ) -> None:
+        # Validate Throughput
+        if billing_mode == "PAY_PER_REQUEST" and throughput:
+            raise MockValidationException(
+                "ProvisionedThroughput cannot be specified when BillingMode is PAY_PER_REQUEST"
+            )
+        if billing_mode == "PROVISIONED" and throughput is None:
+            raise MockValidationException(
+                "One or more parameter values were invalid: ReadCapacityUnits and WriteCapacityUnits must both be specified when BillingMode is PROVISIONED"
+            )
+
+        # Validate KeySchema
+        for idx, _key in enumerate(key_schema, start=1):
+            key_type = _key["KeyType"]
+            if key_type not in ["HASH", "RANGE"]:
+                raise UnknownKeyType(
+                    key_type=key_type, position=f"keySchema.{idx}.member.keyType"
+                )
+        if len(key_schema) > 2:
+            key_elements = [
+                f"KeySchemaElement(attributeName={key.get('AttributeName')}, keyType={key['KeyType']})"
+                for key in key_schema
+            ]
+            provided_keys = ", ".join(key_elements)
+            err = f"1 validation error detected: Value '[{provided_keys}]' at 'keySchema' failed to satisfy constraint: Member must have length less than or equal to 2"
+            raise MockValidationException(err)
+
+        # Validate Global Indexes
+        if global_indexes == []:
+            raise MockValidationException(
+                "One or more parameter values were invalid: List of GlobalSecondaryIndexes is empty"
+            )
+        for idx, g_idx in enumerate(global_indexes or [], start=1):
+            for idx2, _key in enumerate(g_idx["KeySchema"], start=1):
+                key_type = _key["KeyType"]
+                if key_type not in ["HASH", "RANGE"]:
+                    position = f"globalSecondaryIndexes.{idx}.member.keySchema.{idx2}.member.keyType"
+                    raise UnknownKeyType(key_type=key_type, position=position)
+
+        # Validate Local Indexes
+        if local_secondary_indexes == []:
+            raise MockValidationException(
+                "One or more parameter values were invalid: List of LocalSecondaryIndexes is empty"
+            )
+        for idx, g_idx in enumerate(local_secondary_indexes or [], start=1):
+            for idx2, _key in enumerate(g_idx["KeySchema"], start=1):
+                key_type = _key["KeyType"]
+                if key_type not in ["HASH", "RANGE"]:
+                    position = f"localSecondaryIndexes.{idx}.member.keySchema.{idx2}.member.keyType"
+                    raise UnknownKeyType(key_type=key_type, position=position)
+
+        # Validate Attributes
+        expected_attrs = []
+        expected_attrs.extend([key["AttributeName"] for key in key_schema])
+        local_key_schemas = itertools.chain(
+            *list(idx["KeySchema"] for idx in (local_secondary_indexes or []))
+        )
+        expected_attrs.extend(schema["AttributeName"] for schema in local_key_schemas)
+
+        global_key_schemas = itertools.chain(
+            *list(idx["KeySchema"] for idx in (global_indexes or []))
+        )
+        expected_attrs.extend(schema["AttributeName"] for schema in global_key_schemas)
+        expected_attrs = list(set(expected_attrs))
+        expected_attrs.sort()
+        actual_attrs = [item["AttributeName"] for item in attr]
+        actual_attrs.sort()
+        has_index = global_indexes is not None or local_secondary_indexes is not None
+        if actual_attrs != expected_attrs:
+            self._throw_attr_error(actual_attrs, expected_attrs, has_index)
+
     def _throw_attr_error(
         self, actual_attrs: List[str], expected_attrs: List[str], indexes: bool
     ) -> None:
@@ -435,6 +444,7 @@ class DynamoHandler(BaseResponse):
         throughput = self.body.get("ProvisionedThroughput", None)
         billing_mode = self.body.get("BillingMode", None)
         stream_spec = self.body.get("StreamSpecification", None)
+        deletion_protection_enabled = self.body.get("DeletionProtectionEnabled")
         table = self.dynamodb_backend.update_table(
             name=name,
             attr_definitions=attr_definitions,
@@ -442,6 +452,7 @@ class DynamoHandler(BaseResponse):
             throughput=throughput,
             billing_mode=billing_mode,
             stream_spec=stream_spec,
+            deletion_protection_enabled=deletion_protection_enabled,
         )
         return dynamo_json_dump(table.describe())
 
@@ -455,6 +466,9 @@ class DynamoHandler(BaseResponse):
         name = self.body["TableName"]
         item = self.body["Item"]
         return_values = self.body.get("ReturnValues", "NONE")
+        return_values_on_condition_check_failure = self.body.get(
+            "ReturnValuesOnConditionCheckFailure"
+        )
 
         if return_values not in ("ALL_OLD", "NONE"):
             raise MockValidationException("Return values set to invalid value")
@@ -497,6 +511,7 @@ class DynamoHandler(BaseResponse):
             expression_attribute_names,
             expression_attribute_values,
             overwrite,
+            return_values_on_condition_check_failure,
         )
 
         item_dict = result.to_json()
@@ -526,7 +541,12 @@ class DynamoHandler(BaseResponse):
                 elif request_type == "DeleteRequest":
                     keys = request["Key"]
                     delete_requests.append((table_name, keys))
-
+        if self._contains_duplicates(
+            [json.dumps(k[1]) for k in delete_requests]
+        ) or self._contains_duplicates([json.dumps(k[1]) for k in put_requests]):
+            raise MockValidationException(
+                "Provided list of item keys contains duplicates"
+            )
         for table_name, item in put_requests:
             self.dynamodb_backend.put_item(table_name, item)
         for table_name, keys in delete_requests:
@@ -554,10 +574,7 @@ class DynamoHandler(BaseResponse):
         key = self.body["Key"]
         empty_keys = [k for k, v in key.items() if not next(iter(v.values()))]
         if empty_keys:
-            raise MockValidationException(
-                "One or more parameter values are not valid. The AttributeValue for a key attribute cannot contain an "
-                f"empty string value. Key: {empty_keys[0]}"
-            )
+            raise KeyIsEmptyStringException(empty_keys[0])
 
         projection_expression = self._get_projection_expression()
         attributes_to_get = self.body.get("AttributesToGet")
@@ -733,7 +750,9 @@ class DynamoHandler(BaseResponse):
         index_name = self.body.get("IndexName")
         exclusive_start_key = self.body.get("ExclusiveStartKey")
         limit = self.body.get("Limit")
-        scan_index_forward = self.body.get("ScanIndexForward")
+        scan_index_forward = self.body.get("ScanIndexForward", True)
+        consistent_read = self.body.get("ConsistentRead", False)
+
         items, scanned_count, last_evaluated_key = self.dynamodb_backend.query(
             name,
             hash_key,
@@ -744,6 +763,7 @@ class DynamoHandler(BaseResponse):
             scan_index_forward,
             projection_expressions,
             index_name=index_name,
+            consistent_read=consistent_read,
             expr_names=expression_attribute_names,
             expr_values=expression_attribute_values,
             filter_expression=filter_expression,
@@ -804,6 +824,7 @@ class DynamoHandler(BaseResponse):
         exclusive_start_key = self.body.get("ExclusiveStartKey")
         limit = self.body.get("Limit")
         index_name = self.body.get("IndexName")
+        consistent_read = self.body.get("ConsistentRead", False)
 
         projection_expressions = self._adjust_projection_expression(
             projection_expression, expression_attribute_names
@@ -819,6 +840,7 @@ class DynamoHandler(BaseResponse):
                 expression_attribute_names,
                 expression_attribute_values,
                 index_name,
+                consistent_read,
                 projection_expressions,
             )
         except ValueError as err:
@@ -967,12 +989,11 @@ class DynamoHandler(BaseResponse):
                 if len(changed) != len(original):
                     return changed
                 else:
-                    return [
-                        self._build_updated_new_attributes(
-                            original[index], changed[index]
-                        )
+                    any_element_has_changed = any(
+                        changed[index] != original[index]
                         for index in range(len(changed))
-                    ]
+                    )
+                    return changed if any_element_has_changed else original
             else:
                 return changed
 
@@ -1069,6 +1090,18 @@ class DynamoHandler(BaseResponse):
                 item_attrs = item["Put"]["Item"]
                 table = self.dynamodb_backend.get_table(item["Put"]["TableName"])
                 validate_put_has_empty_keys(item_attrs, table)
+            if "Update" in item:
+                item_attrs = item["Update"]["Key"]
+                table = self.dynamodb_backend.get_table(item["Update"]["TableName"])
+                validate_put_has_empty_keys(
+                    item_attrs,
+                    table,
+                    custom_error_msg="One or more parameter values are not valid. The AttributeValue for a key attribute cannot contain an empty string value. Key: {}",
+                )
+                update_expression = item["Update"]["UpdateExpression"]
+                UpdateExpressionParser.make(update_expression).validate(
+                    limit_set_actions=True
+                )
         self.dynamodb_backend.transact_write_items(transact_items)
         response: Dict[str, Any] = {"ConsumedCapacity": [], "ItemCollectionMetrics": {}}
         return dynamo_json_dump(response)
@@ -1154,3 +1187,81 @@ class DynamoHandler(BaseResponse):
         stmts = self.body.get("Statements", [])
         items = self.dynamodb_backend.batch_execute_statement(stmts)
         return dynamo_json_dump({"Responses": items})
+
+    def import_table(self) -> str:
+        params = self.body
+        s3_source = params.get("S3BucketSource")
+        input_format = params.get("InputFormat") or "DYNAMODB_JSON"
+        compression_type = params.get("InputCompressionType") or "NONE"
+        table_parameters = params.get("TableCreationParameters")
+        table_name = table_parameters["TableName"]
+        table_attrs = table_parameters["AttributeDefinitions"]
+        table_schema = table_parameters["KeySchema"]
+        table_billing = table_parameters.get("BillingMode")
+        table_throughput = table_parameters.get("ProvisionedThroughput")
+        global_indexes = table_parameters.get("GlobalSecondaryIndexes")
+
+        self._validate_table_creation(
+            billing_mode=table_billing,
+            throughput=table_throughput,
+            key_schema=table_schema,
+            global_indexes=global_indexes,
+            local_secondary_indexes=None,
+            attr=table_attrs,
+        )
+
+        import_table = self.dynamodb_backend.import_table(
+            s3_source=s3_source,
+            input_format=input_format,
+            compression_type=compression_type,
+            table_name=table_name,
+            billing_mode=table_billing or "PROVISIONED",
+            throughput=table_throughput,
+            key_schema=table_schema,
+            global_indexes=global_indexes,
+            attrs=table_attrs,
+        )
+        return json.dumps({"ImportTableDescription": import_table.response()})
+
+    def describe_import(self) -> str:
+        import_arn = self.body["ImportArn"]
+        import_table = self.dynamodb_backend.describe_import(import_arn)
+        return json.dumps({"ImportTableDescription": import_table.response()})
+
+    def export_table_to_point_in_time(self) -> str:
+        table_arn = self.body["TableArn"]
+        s3_bucket = self.body["S3Bucket"]
+        s3_prefix = self.body["S3Prefix"]
+        export_type = self.body.get("ExportType", "FULL_EXPORT")
+        export_format = self.body.get("ExportFormat", "DYNAMO_JSON")
+        s3_bucket_owner = self.body.get("S3BucketOwner")
+
+        export_table = self.dynamodb_backend.export_table(
+            s3_bucket=s3_bucket,
+            s3_prefix=s3_prefix,
+            table_arn=table_arn,
+            export_type=export_type,
+            export_format=export_format,
+            s3_bucket_owner=s3_bucket_owner,
+        )
+
+        return dynamo_json_dump({"ExportDescription": export_table.response()})
+
+    def describe_export(self) -> str:
+        export_arn = self.body["ExportArn"]
+        export_table = self.dynamodb_backend.describe_export(export_arn)
+        return json.dumps({"ExportDescription": export_table.response()})
+
+    def list_exports(self) -> str:
+        table_arn = self.body["TableArn"]
+        exports = self.dynamodb_backend.list_exports(table_arn)
+        response = []
+        for export_table in exports:
+            response.append(
+                {
+                    "ExportArn": export_table.arn,
+                    "ExportStatus": export_table.status,
+                    "ExportType": export_table.export_type,
+                }
+            )
+        return json.dumps({"ExportSummaries": response})
