@@ -499,6 +499,14 @@ class InvalidInternetGatewayIdError(EC2ClientError):
         )
 
 
+class InvalidGroupIdMalformedError(EC2ClientError):
+    def __init__(self, group_id: str):
+        super().__init__(
+            "InvalidGroupId.Malformed",
+            f"The security group ID '{group_id}' is malformed",
+        )
+
+
 class GatewayNotAttachedError(EC2ClientError):
     def __init__(self, internet_gateway_id: str, vpc_id: str):
         super().__init__(
@@ -572,7 +580,7 @@ class UnsupportedTenancy(EC2ClientError):
         )
 
 
-class OperationNotPermitted(EC2ClientError):
+class VPCCidrBlockAssociationError(EC2ClientError):
     def __init__(self, association_id: str):
         super().__init__(
             "OperationNotPermitted",
@@ -580,6 +588,18 @@ class OperationNotPermitted(EC2ClientError):
         )
 
 
+class OperationNotPermitted(EC2ClientError):
+    def __init__(self, message: str):
+        super().__init__("OperationNotPermitted", message)
+
+
+class LastEniDetachError(OperationNotPermitted):
+    def __init__(self) -> None:
+        super().__init__(
+            "The network interface at device index 0 and networkCard index 0 cannot be detached."
+        )
+
+
 class InvalidAvailabilityZoneError(EC2ClientError):
     def __init__(
         self, availability_zone_value: Optional[str], valid_availability_zones: str
