@@ -1,25 +1,25 @@
 import copy
 import json
-import os
 import re
 import sys
 import warnings
 from collections import OrderedDict
-from datetime import datetime
 from enum import Enum, unique
 from json import JSONDecodeError
 from operator import eq, ge, gt, le, lt
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional
 
 import requests
 
 from moto import settings
-from moto.core import BackendDict, BaseBackend, BaseModel, CloudFormationModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel, CloudFormationModel
 from moto.core.exceptions import JsonRESTError
 from moto.core.utils import (
     iso_8601_datetime_without_milliseconds,
     unix_time,
     unix_time_millis,
+    utcfromtimestamp,
 )
 from moto.events.exceptions import (
     IllegalStatusException,
@@ -32,8 +32,9 @@ from moto.moto_api._internal import mock_random as random
 from moto.utilities.arns import parse_arn
 from moto.utilities.paginator import paginate
 from moto.utilities.tagging_service import TaggingService
+from moto.utilities.utils import ARN_PARTITION_REGEX, get_partition
 
-from .utils import PAGINATION_MODEL
+from .utils import _BASE_EVENT_MESSAGE, PAGINATION_MODEL, EventMessageType
 
 # Sentinel to signal the absence of a field for `Exists` pattern matching
 UNDEFINED = object()
@@ -73,7 +74,7 @@ class Rule(CloudFormationModel):
             "" if self.event_bus_name == "default" else f"{self.event_bus_name}/"
         )
 
-        return f"arn:aws:events:{self.region_name}:{self.account_id}:rule/{event_bus_name}{self.name}"
+        return f"arn:{get_partition(self.region_name)}:events:{self.region_name}:{self.account_id}:rule/{event_bus_name}{self.name}"
 
     @property
     def physical_resource_id(self) -> str:
@@ -112,7 +113,7 @@ class Rule(CloudFormationModel):
             if index is not None:
                 self.targets.pop(index)
 
-    def send_to_targets(self, event: Dict[str, Any]) -> None:
+    def send_to_targets(self, event: EventMessageType) -> None:
         if not self.event_pattern.matches_event(event):
             return
 
@@ -165,12 +166,12 @@ class Rule(CloudFormationModel):
             else:
                 raise NotImplementedError(f"Expr not defined for {type(self)}")
 
-    def _send_to_cw_log_group(self, name: str, event: Dict[str, Any]) -> None:
+    def _send_to_cw_log_group(self, name: str, event: EventMessageType) -> None:
         from moto.logs import logs_backends
 
         event_copy = copy.deepcopy(event)
         event_copy["time"] = iso_8601_datetime_without_milliseconds(
-            datetime.utcfromtimestamp(event_copy["time"])
+            utcfromtimestamp(event_copy["time"])  # type: ignore[arg-type]
         )
 
         log_stream_name = str(random.uuid4())
@@ -182,13 +183,15 @@ class Rule(CloudFormationModel):
         log_backend.create_log_stream(name, log_stream_name)
         log_backend.put_log_events(name, log_stream_name, log_events)
 
-    def _send_to_events_archive(self, resource_id: str, event: Dict[str, Any]) -> None:
+    def _send_to_events_archive(
+        self, resource_id: str, event: EventMessageType
+    ) -> None:
         archive_name, archive_uuid = resource_id.split(":")
         archive = events_backends[self.account_id][self.region_name].archives.get(
             archive_name
         )
         if archive.uuid == archive_uuid:  # type: ignore[union-attr]
-            archive.events.append(event)  # type: ignore[arg-type,union-attr]
+            archive.events.append(event)  # type: ignore[union-attr]
 
     def _find_api_destination(self, resource_id: str) -> "Destination":
         backend: "EventsBackend" = events_backends[self.account_id][self.region_name]
@@ -196,13 +199,13 @@ class Rule(CloudFormationModel):
         return backend.destinations[destination_name]
 
     def _send_to_sqs_queue(
-        self, resource_id: str, event: Dict[str, Any], group_id: Optional[str] = None
+        self, resource_id: str, event: EventMessageType, group_id: Optional[str] = None
     ) -> None:
         from moto.sqs import sqs_backends
 
         event_copy = copy.deepcopy(event)
         event_copy["time"] = iso_8601_datetime_without_milliseconds(
-            datetime.utcfromtimestamp(event_copy["time"])
+            utcfromtimestamp(event_copy["time"])  # type: ignore[arg-type]
         )
 
         if group_id:
@@ -339,7 +342,7 @@ class EventBus(CloudFormationModel):
         self.account_id = account_id
         self.region = region_name
         self.name = name
-        self.arn = f"arn:aws:events:{self.region}:{account_id}:event-bus/{name}"
+        self.arn = f"arn:{get_partition(self.region)}:events:{self.region}:{account_id}:event-bus/{name}"
         self.tags = tags or []
 
         self._statements: Dict[str, EventBusPolicyStatement] = {}
@@ -551,12 +554,12 @@ class Archive(CloudFormationModel):
         self.event_pattern = EventPattern.load(event_pattern)
         self.retention = retention if retention else 0
 
-        self.arn = f"arn:aws:events:{region_name}:{account_id}:archive/{name}"
+        self.arn = f"arn:{get_partition(region_name)}:events:{region_name}:{account_id}:archive/{name}"
         self.creation_time = unix_time()
         self.state = "ENABLED"
         self.uuid = str(random.uuid4())
 
-        self.events: List[str] = []
+        self.events: List[EventMessageType] = []
         self.event_bus_name = source_arn.split("/")[-1]
 
     def describe_short(self) -> Dict[str, Any]:
@@ -699,7 +702,7 @@ class Replay(BaseModel):
         self.event_end_time = end_time
         self.destination = destination
 
-        self.arn = f"arn:aws:events:{region_name}:{account_id}:replay/{name}"
+        self.arn = f"arn:{get_partition(region_name)}:events:{region_name}:{account_id}:replay/{name}"
         self.state = ReplayState.STARTING
         self.start_time = unix_time()
         self.end_time: Optional[float] = None
@@ -735,7 +738,8 @@ class Replay(BaseModel):
             for rule in event_bus.rules.values():
                 rule.send_to_targets(
                     dict(
-                        event, **{"id": str(random.uuid4()), "replay-name": self.name}  # type: ignore
+                        event,
+                        **{"id": str(random.uuid4()), "replay-name": self.name},  # type: ignore
                     ),
                 )
 
@@ -762,7 +766,7 @@ class Connection(BaseModel):
         self.creation_time = unix_time()
         self.state = "AUTHORIZED"
 
-        self.arn = f"arn:aws:events:{region_name}:{account_id}:connection/{self.name}/{self.uuid}"
+        self.arn = f"arn:{get_partition(region_name)}:events:{region_name}:{account_id}:connection/{self.name}/{self.uuid}"
 
     def describe_short(self) -> Dict[str, Any]:
         """
@@ -839,7 +843,7 @@ class Destination(BaseModel):
         self.creation_time = unix_time()
         self.http_method = http_method
         self.state = "ACTIVE"
-        self.arn = f"arn:aws:events:{region_name}:{account_id}:api-destination/{name}/{self.uuid}"
+        self.arn = f"arn:{get_partition(region_name)}:events:{region_name}:{account_id}:api-destination/{name}/{self.uuid}"
 
     def describe(self) -> Dict[str, Any]:
         return {
@@ -872,16 +876,18 @@ class EventPattern:
     def get_pattern(self) -> Dict[str, Any]:
         return self._pattern
 
-    def matches_event(self, event: Dict[str, Any]) -> bool:
+    def matches_event(self, event: EventMessageType) -> bool:
         if not self._pattern:
             return True
         event = json.loads(json.dumps(event))
         return self._does_event_match(event, self._pattern)
 
-    def _does_event_match(self, event: Dict[str, Any], pattern: Dict[str, Any]) -> bool:
+    def _does_event_match(
+        self, event: EventMessageType, pattern: Dict[str, Any]
+    ) -> bool:
         items_and_filters = [(event.get(k, UNDEFINED), v) for k, v in pattern.items()]
         nested_filter_matches = [
-            self._does_event_match(item, nested_filter)
+            self._does_event_match(item, nested_filter)  # type: ignore
             for item, nested_filter in items_and_filters
             if isinstance(nested_filter, dict)
         ]
@@ -969,7 +975,7 @@ class EventPatternParser:
 class PartnerEventSource(BaseModel):
     def __init__(self, region: str, name: str):
         self.name = name
-        self.arn = f"arn:aws:events:{region}::event-source/aws.partner/{name}"
+        self.arn = f"arn:{get_partition(region)}:events:{region}::event-source/aws.partner/{name}"
         self.created_on = unix_time()
         self.accounts: List[str] = []
         self.state = "ACTIVE"
@@ -1020,46 +1026,11 @@ class EventsBackend(BaseBackend):
         self.partner_event_sources: Dict[str, PartnerEventSource] = {}
         self.approved_parent_event_bus_names: List[str] = []
 
-    @staticmethod
-    def default_vpc_endpoint_service(
-        service_region: str, zones: List[str]
-    ) -> List[Dict[str, str]]:
-        """Default VPC endpoint service."""
-        return BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "events"
-        )
-
     def _add_default_event_bus(self) -> None:
         self.event_buses["default"] = EventBus(
             self.account_id, self.region_name, "default"
         )
 
-    def _gen_next_token(self, index: int) -> str:
-        token = os.urandom(128).encode("base64")  # type: ignore
-        self.next_tokens[token] = index
-        return token
-
-    def _process_token_and_limits(
-        self,
-        array_len: int,
-        next_token: Optional[str] = None,
-        limit: Optional[str] = None,
-    ) -> Tuple[int, int, Optional[str]]:
-        start_index = 0
-        end_index = array_len
-        new_next_token: Optional[str] = None
-
-        if next_token:
-            start_index = self.next_tokens.pop(next_token, 0)
-
-        if limit is not None:
-            new_end_index = start_index + int(limit)
-            if new_end_index < end_index:
-                end_index = new_end_index
-                new_next_token = self._gen_next_token(end_index)
-
-        return start_index, end_index, new_next_token
-
     def _get_event_bus(self, name: str) -> EventBus:
         event_bus_name = name.split(f"{self.account_id}:event-bus/")[-1]
 
@@ -1178,7 +1149,7 @@ class EventsBackend(BaseBackend):
 
         return False
 
-    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)
     def list_rule_names_by_target(
         self, target_arn: str, event_bus_arn: Optional[str]
     ) -> List[Rule]:
@@ -1193,7 +1164,7 @@ class EventsBackend(BaseBackend):
 
         return matching_rules
 
-    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)
     def list_rules(
         self, prefix: Optional[str] = None, event_bus_arn: Optional[str] = None
     ) -> List[Rule]:
@@ -1213,34 +1184,16 @@ class EventsBackend(BaseBackend):
 
         return matching_rules
 
-    def list_targets_by_rule(
-        self,
-        rule_id: str,
-        event_bus_arn: Optional[str],
-        next_token: Optional[str] = None,
-        limit: Optional[str] = None,
-    ) -> Dict[str, Any]:
+    @paginate(pagination_model=PAGINATION_MODEL)
+    def list_targets_by_rule(  # type: ignore[misc]
+        self, rule_id: str, event_bus_arn: Optional[str]
+    ) -> List[Dict[str, Any]]:
         # We'll let a KeyError exception be thrown for response to handle if
         # rule doesn't exist.
         event_bus_name = self._normalize_event_bus_arn(event_bus_arn)
         event_bus = self._get_event_bus(event_bus_name)
         rule = event_bus.rules[rule_id]
-
-        start_index, end_index, new_next_token = self._process_token_and_limits(
-            len(rule.targets), next_token, limit
-        )
-
-        returned_targets: List[Dict[str, Any]] = []
-        return_obj: Dict[str, Any] = {}
-
-        for i in range(start_index, end_index):
-            returned_targets.append(rule.targets[i])
-
-        return_obj["Targets"] = returned_targets
-        if new_next_token is not None:
-            return_obj["NextToken"] = new_next_token
-
-        return return_obj
+        return rule.targets
 
     def put_targets(
         self, name: str, event_bus_arn: Optional[str], targets: List[Dict[str, Any]]
@@ -1304,21 +1257,21 @@ class EventsBackend(BaseBackend):
 
         entries = []
         for event in events:
-            if "Source" not in event:
+            if not event.get("Source"):
                 entries.append(
                     {
                         "ErrorCode": "InvalidArgument",
                         "ErrorMessage": "Parameter Source is not valid. Reason: Source is a required argument.",
                     }
                 )
-            elif "DetailType" not in event:
+            elif not event.get("DetailType"):
                 entries.append(
                     {
                         "ErrorCode": "InvalidArgument",
                         "ErrorMessage": "Parameter DetailType is not valid. Reason: DetailType is a required argument.",
                     }
                 )
-            elif "Detail" not in event:
+            elif not event.get("Detail"):
                 entries.append(
                     {
                         "ErrorCode": "InvalidArgument",
@@ -1351,19 +1304,16 @@ class EventsBackend(BaseBackend):
 
                 event_bus = self.describe_event_bus(event_bus_name)
                 for rule in event_bus.rules.values():
-                    rule.send_to_targets(
-                        {
-                            "version": "0",
-                            "id": event_id,
-                            "detail-type": event["DetailType"],
-                            "source": event["Source"],
-                            "account": self.account_id,
-                            "time": event.get("Time", unix_time()),
-                            "region": self.region_name,
-                            "resources": event.get("Resources", []),
-                            "detail": json.loads(event["Detail"]),
-                        },
-                    )
+                    event_msg = copy.deepcopy(_BASE_EVENT_MESSAGE)
+                    event_msg["id"] = event_id
+                    event_msg["detail-type"] = event["DetailType"]
+                    event_msg["source"] = event["Source"]
+                    event_msg["account"] = self.account_id
+                    event_msg["time"] = event.get("Time", unix_time())
+                    event_msg["region"] = self.region_name
+                    event_msg["resources"] = event.get("Resources", [])
+                    event_msg["detail"] = json.loads(event["Detail"])
+                    rule.send_to_targets(event_msg)
 
         return entries
 
@@ -1395,7 +1345,9 @@ class EventsBackend(BaseBackend):
             )
 
     @staticmethod
-    def _condition_param_to_stmt_condition(condition: Optional[Dict[str, Any]]) -> Optional[Dict[str, Any]]:  # type: ignore[misc]
+    def _condition_param_to_stmt_condition(  # type: ignore[misc]
+        condition: Optional[Dict[str, Any]],
+    ) -> Optional[Dict[str, Any]]:
         if condition:
             key = condition["Key"]
             value = condition["Value"]
@@ -1440,7 +1392,9 @@ class EventsBackend(BaseBackend):
                 "InvalidParameterValue", r"StatementId must match ^[a-zA-Z0-9-_]{1,64}$"
             )
 
-        principal_arn = {"AWS": f"arn:aws:iam::{principal}:root"}
+        principal_arn = {
+            "AWS": f"arn:{get_partition(self.region_name)}:iam::{principal}:root"
+        }
         stmt_condition = self._condition_param_to_stmt_condition(condition)
         event_bus.add_permission(statement_id, action, principal_arn, stmt_condition)
 
@@ -1625,7 +1579,7 @@ class EventsBackend(BaseBackend):
             [
                 {
                     "Id": rule.name,
-                    "Arn": f"arn:aws:events:{self.region_name}:::",
+                    "Arn": f"arn:{get_partition(self.region_name)}:events:{self.region_name}:::",
                     "InputTransformer": {
                         "InputPathsMap": {},
                         "InputTemplate": json.dumps(
@@ -1721,7 +1675,9 @@ class EventsBackend(BaseBackend):
         destination: Dict[str, Any],
     ) -> Dict[str, Any]:
         event_bus_arn = destination["Arn"]
-        event_bus_arn_pattern = r"^arn:aws:events:[a-zA-Z0-9-]+:\d{12}:event-bus/"
+        event_bus_arn_pattern = (
+            rf"{ARN_PARTITION_REGEX}:events:[a-zA-Z0-9-]+:\d{{12}}:event-bus/"
+        )
         if not re.match(event_bus_arn_pattern, event_bus_arn):
             raise ValidationException(
                 "Parameter Destination.Arn is not valid. Reason: Must contain an event bus ARN."
