@@ -1,8 +1,10 @@
 from datetime import datetime
 from typing import Any, Dict, List, Optional
 
-from moto.core import BackendDict, BaseBackend, BaseModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel
 from moto.moto_api._internal import mock_random
+from moto.utilities.utils import get_partition
 
 from .exceptions import DetectorNotFoundException, FilterNotFoundException
 
@@ -29,6 +31,7 @@ class GuardDutyBackend(BaseBackend):
 
         detector = Detector(
             account_id=self.account_id,
+            region_name=self.region_name,
             created_at=datetime.now(),
             finding_publish_freq=finding_publishing_frequency,
             enabled=enable,
@@ -159,6 +162,7 @@ class Detector(BaseModel):
     def __init__(
         self,
         account_id: str,
+        region_name: str,
         created_at: datetime,
         finding_publish_freq: str,
         enabled: bool,
@@ -168,7 +172,7 @@ class Detector(BaseModel):
         self.id = mock_random.get_random_hex(length=32)
         self.created_at = created_at
         self.finding_publish_freq = finding_publish_freq
-        self.service_role = f"arn:aws:iam::{account_id}:role/aws-service-role/guardduty.amazonaws.com/AWSServiceRoleForAmazonGuardDuty"
+        self.service_role = f"arn:{get_partition(region_name)}:iam::{account_id}:role/aws-service-role/guardduty.amazonaws.com/AWSServiceRoleForAmazonGuardDuty"
         self.enabled = enabled
         self.updated_at = created_at
         self.datasources = datasources or {}
