@@ -1,42 +1,22 @@
 from collections import defaultdict
 from typing import Any, Dict, Iterable, List
 
-from moto.core.common_types import TYPE_RESPONSE
 from moto.core.responses import BaseResponse
 from moto.ec2.models import ec2_backends
-from moto.neptune.responses import (
-    CREATE_GLOBAL_CLUSTER_TEMPLATE,
-    DELETE_GLOBAL_CLUSTER_TEMPLATE,
-    DESCRIBE_GLOBAL_CLUSTERS_TEMPLATE,
-    REMOVE_FROM_GLOBAL_CLUSTER_TEMPLATE,
-    NeptuneResponse,
-)
 
 from .exceptions import DBParameterGroupNotFoundError
 from .models import RDSBackend, rds_backends
 
 
 class RDSResponse(BaseResponse):
-    def __init__(self) -> None:
-        super().__init__(service_name="rds")
-        # Neptune and RDS share a HTTP endpoint RDS is the lucky guy that catches all requests
-        # So we have to determine whether we can handle an incoming request here, or whether it needs redirecting to Neptune
-        self.neptune = NeptuneResponse()
-
     @property
     def backend(self) -> RDSBackend:
         return rds_backends[self.current_account][self.region]
 
-    def _dispatch(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:
-        # Because some requests are send through to Neptune, we have to prepare the NeptuneResponse-class
-        self.neptune.setup_class(request, full_url, headers)
-        return super()._dispatch(request, full_url, headers)
-
-    def __getattribute__(self, name: str) -> Any:
-        if name in ["create_db_cluster", "create_global_cluster"]:
-            if self._get_param("Engine") == "neptune":
-                return object.__getattribute__(self.neptune, name)
-        return object.__getattribute__(self, name)
+    @property
+    def global_backend(self) -> RDSBackend:
+        """Return backend instance of the region that stores Global Clusters"""
+        return rds_backends[self.current_account]["us-east-1"]
 
     def _get_db_kwargs(self) -> Dict[str, Any]:
         args = {
@@ -75,12 +55,10 @@ class RDSResponse(BaseResponse):
                 "PreferredMaintenanceWindow", "wed:06:38-wed:07:08"
             ).lower(),
             "publicly_accessible": self._get_param("PubliclyAccessible"),
-            "account_id": self.current_account,
-            "region": self.region,
             "security_groups": self._get_multi_param(
                 "DBSecurityGroups.DBSecurityGroupName"
             ),
-            "storage_encrypted": self._get_param("StorageEncrypted"),
+            "storage_encrypted": self._get_bool_param("StorageEncrypted"),
             "storage_type": self._get_param("StorageType", None),
             "vpc_security_group_ids": self._get_multi_param(
                 "VpcSecurityGroupIds.VpcSecurityGroupId"
@@ -97,6 +75,7 @@ class RDSResponse(BaseResponse):
             "allocated_storage": self._get_int_param("AllocatedStorage"),
             "availability_zone": self._get_param("AvailabilityZone"),
             "backup_retention_period": self._get_param("BackupRetentionPeriod"),
+            "backtrack_window": self._get_param("BacktrackWindow"),
             "copy_tags_to_snapshot": self._get_param("CopyTagsToSnapshot"),
             "db_instance_class": self._get_param("DBInstanceClass"),
             "db_cluster_identifier": self._get_param("DBClusterIdentifier"),
@@ -131,12 +110,10 @@ class RDSResponse(BaseResponse):
                 "PreferredMaintenanceWindow"
             ),
             "publicly_accessible": self._get_param("PubliclyAccessible"),
-            "account_id": self.current_account,
-            "region": self.region,
             "security_groups": self._get_multi_param(
                 "DBSecurityGroups.DBSecurityGroupName"
             ),
-            "storage_encrypted": self._get_param("StorageEncrypted"),
+            "storage_encrypted": self._get_bool_param("StorageEncrypted"),
             "storage_type": self._get_param("StorageType", None),
             "vpc_security_group_ids": self._get_multi_param(
                 "VpcSecurityGroupIds.VpcSecurityGroupId"
@@ -184,7 +161,11 @@ class RDSResponse(BaseResponse):
             "availability_zones": self._get_multi_param(
                 "AvailabilityZones.AvailabilityZone"
             ),
+            "backtrack_window": self._get_int_param("BacktrackWindow"),
             "enable_cloudwatch_logs_exports": params.get("EnableCloudwatchLogsExports"),
+            "enable_iam_database_authentication": self._get_bool_param(
+                "EnableIAMDatabaseAuthentication"
+            ),
             "db_name": self._get_param("DatabaseName"),
             "db_cluster_identifier": self._get_param("DBClusterIdentifier"),
             "db_subnet_group_name": self._get_param("DBSubnetGroupName"),
@@ -195,6 +176,10 @@ class RDSResponse(BaseResponse):
             "allocated_storage": self._get_param("AllocatedStorage"),
             "global_cluster_identifier": self._get_param("GlobalClusterIdentifier"),
             "iops": self._get_param("Iops"),
+            "storage_encrypted": self._get_bool_param("StorageEncrypted"),
+            "enable_global_write_forwarding": self._get_param(
+                "EnableGlobalWriteForwarding"
+            ),
             "storage_type": self._get_param("StorageType"),
             "kms_key_id": self._get_param("KmsKeyId"),
             "master_username": self._get_param("MasterUsername"),
@@ -202,10 +187,9 @@ class RDSResponse(BaseResponse):
             "network_type": self._get_param("NetworkType"),
             "port": self._get_param("Port"),
             "parameter_group": self._get_param("DBClusterParameterGroupName"),
-            "region": self.region,
             "db_cluster_instance_class": self._get_param("DBClusterInstanceClass"),
             "enable_http_endpoint": self._get_bool_param("EnableHttpEndpoint"),
-            "copy_tags_to_snapshot": self._get_param("CopyTagsToSnapshot"),
+            "copy_tags_to_snapshot": self._get_bool_param("CopyTagsToSnapshot"),
             "tags": self.unpack_list_params("Tags", "Tag"),
             "scaling_configuration": self._get_dict_param("ScalingConfiguration."),
             "serverless_v2_scaling_configuration": params.get(
@@ -217,6 +201,8 @@ class RDSResponse(BaseResponse):
             "vpc_security_group_ids": self.unpack_list_params(
                 "VpcSecurityGroupIds", "VpcSecurityGroupId"
             ),
+            "preferred_backup_window": self._get_param("PreferredBackupWindow"),
+            "backup_retention_period": self._get_param("BackupRetentionPeriod"),
         }
 
     def _get_export_task_kwargs(self) -> Dict[str, Any]:
@@ -239,7 +225,7 @@ class RDSResponse(BaseResponse):
                 "EventCategories", "EventCategory"
             ),
             "source_ids": self.unpack_list_params("SourceIds", "SourceId"),
-            "enabled": self._get_param("Enabled"),
+            "enabled": self._get_bool_param("Enabled"),
             "tags": self.unpack_list_params("Tags", "Tag"),
         }
 
@@ -367,6 +353,17 @@ class RDSResponse(BaseResponse):
         template = self.response_template(RESTORE_INSTANCE_FROM_SNAPSHOT_TEMPLATE)
         return template.render(database=new_instance)
 
+    def restore_db_instance_to_point_in_time(self) -> str:
+        source_db_identifier = self._get_param("SourceDBInstanceIdentifier")
+        target_db_identifier = self._get_param("TargetDBInstanceIdentifier")
+
+        db_kwargs = self._get_db_kwargs()
+        new_instance = self.backend.restore_db_instance_to_point_in_time(
+            source_db_identifier, target_db_identifier, db_kwargs
+        )
+        template = self.response_template(RESTORE_INSTANCE_TO_POINT_IN_TIME_TEMPLATE)
+        return template.render(database=new_instance)
+
     def list_tags_for_resource(self) -> str:
         arn = self._get_param("ResourceName")
         template = self.response_template(LIST_TAGS_FOR_RESOURCE_TEMPLATE)
@@ -739,13 +736,13 @@ class RDSResponse(BaseResponse):
         return template.render(options=options, marker=None)
 
     def describe_global_clusters(self) -> str:
-        clusters = self.backend.describe_global_clusters()
+        clusters = self.global_backend.describe_global_clusters()
         template = self.response_template(DESCRIBE_GLOBAL_CLUSTERS_TEMPLATE)
         return template.render(clusters=clusters)
 
     def create_global_cluster(self) -> str:
         params = self._get_params()
-        cluster = self.backend.create_global_cluster(
+        cluster = self.global_backend.create_global_cluster(
             global_cluster_identifier=params["GlobalClusterIdentifier"],
             source_db_cluster_identifier=params.get("SourceDBClusterIdentifier"),
             engine=params.get("Engine"),
@@ -758,7 +755,7 @@ class RDSResponse(BaseResponse):
 
     def delete_global_cluster(self) -> str:
         params = self._get_params()
-        cluster = self.backend.delete_global_cluster(
+        cluster = self.global_backend.delete_global_cluster(
             global_cluster_identifier=params["GlobalClusterIdentifier"],
         )
         template = self.response_template(DELETE_GLOBAL_CLUSTER_TEMPLATE)
@@ -807,6 +804,106 @@ class RDSResponse(BaseResponse):
         template = self.response_template(PROMOTE_READ_REPLICA_DB_CLUSTER_TEMPLATE)
         return template.render(cluster=cluster)
 
+    def describe_db_snapshot_attributes(self) -> str:
+        params = self._get_params()
+        db_snapshot_identifier = params["DBSnapshotIdentifier"]
+        db_snapshot_attributes_result = self.backend.describe_db_snapshot_attributes(
+            db_snapshot_identifier=db_snapshot_identifier,
+        )
+        template = self.response_template(DESCRIBE_DB_SNAPSHOT_ATTRIBUTES_TEMPLATE)
+        return template.render(
+            db_snapshot_attributes_result=db_snapshot_attributes_result,
+            db_snapshot_identifier=db_snapshot_identifier,
+        )
+
+    def modify_db_snapshot_attribute(self) -> str:
+        params = self._get_params()
+        db_snapshot_identifier = params["DBSnapshotIdentifier"]
+        db_snapshot_attributes_result = self.backend.modify_db_snapshot_attribute(
+            db_snapshot_identifier=db_snapshot_identifier,
+            attribute_name=params["AttributeName"],
+            values_to_add=params.get("ValuesToAdd"),
+            values_to_remove=params.get("ValuesToRemove"),
+        )
+        template = self.response_template(MODIFY_DB_SNAPSHOT_ATTRIBUTE_TEMPLATE)
+        return template.render(
+            db_snapshot_attributes_result=db_snapshot_attributes_result,
+            db_snapshot_identifier=db_snapshot_identifier,
+        )
+
+    def describe_db_cluster_snapshot_attributes(self) -> str:
+        params = self._get_params()
+        db_cluster_snapshot_identifier = params["DBClusterSnapshotIdentifier"]
+        db_cluster_snapshot_attributes_result = (
+            self.backend.describe_db_cluster_snapshot_attributes(
+                db_cluster_snapshot_identifier=db_cluster_snapshot_identifier,
+            )
+        )
+        template = self.response_template(
+            DESCRIBE_DB_CLUSTER_SNAPSHOT_ATTRIBUTES_TEMPLATE
+        )
+        return template.render(
+            db_cluster_snapshot_attributes_result=db_cluster_snapshot_attributes_result,
+            db_cluster_snapshot_identifier=db_cluster_snapshot_identifier,
+        )
+
+    def modify_db_cluster_snapshot_attribute(self) -> str:
+        params = self._get_params()
+        db_cluster_snapshot_identifier = params["DBClusterSnapshotIdentifier"]
+        db_cluster_snapshot_attributes_result = (
+            self.backend.modify_db_cluster_snapshot_attribute(
+                db_cluster_snapshot_identifier=db_cluster_snapshot_identifier,
+                attribute_name=params["AttributeName"],
+                values_to_add=params.get("ValuesToAdd"),
+                values_to_remove=params.get("ValuesToRemove"),
+            )
+        )
+        template = self.response_template(MODIFY_DB_CLUSTER_SNAPSHOT_ATTRIBUTE_TEMPLATE)
+        return template.render(
+            db_cluster_snapshot_attributes_result=db_cluster_snapshot_attributes_result,
+            db_cluster_snapshot_identifier=db_cluster_snapshot_identifier,
+        )
+
+    def describe_db_proxies(self) -> str:
+        params = self._get_params()
+        db_proxy_name = params.get("DBProxyName")
+        # filters = params.get("Filters")
+        marker = params.get("Marker")
+        db_proxies = self.backend.describe_db_proxies(
+            db_proxy_name=db_proxy_name,
+            # filters=filters,
+        )
+        template = self.response_template(DESCRIBE_DB_PROXIES_TEMPLATE)
+        rendered = template.render(dbproxies=db_proxies, marker=marker)
+        return rendered
+
+    def create_db_proxy(self) -> str:
+        params = self._get_params()
+        db_proxy_name = params["DBProxyName"]
+        engine_family = params["EngineFamily"]
+        auth = params["Auth"]
+        role_arn = params["RoleArn"]
+        vpc_subnet_ids = params["VpcSubnetIds"]
+        vpc_security_group_ids = params.get("VpcSecurityGroupIds")
+        require_tls = params.get("RequireTLS")
+        idle_client_timeout = params.get("IdleClientTimeout")
+        debug_logging = params.get("DebugLogging")
+        tags = self.unpack_list_params("Tags", "Tag")
+        db_proxy = self.backend.create_db_proxy(
+            db_proxy_name=db_proxy_name,
+            engine_family=engine_family,
+            auth=auth,
+            role_arn=role_arn,
+            vpc_subnet_ids=vpc_subnet_ids,
+            vpc_security_group_ids=vpc_security_group_ids,
+            require_tls=require_tls,
+            idle_client_timeout=idle_client_timeout,
+            debug_logging=debug_logging,
+            tags=tags,
+        )
+        template = self.response_template(CREATE_DB_PROXY_TEMPLATE)
+        return template.render(dbproxy=db_proxy)
+
 
 CREATE_DATABASE_TEMPLATE = """<CreateDBInstanceResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <CreateDBInstanceResult>
@@ -914,6 +1011,16 @@ RESTORE_INSTANCE_FROM_SNAPSHOT_TEMPLATE = """<RestoreDBInstanceFromDBSnapshotRes
   </ResponseMetadata>
 </RestoreDBInstanceFromDBSnapshotResponse>"""
 
+
+RESTORE_INSTANCE_TO_POINT_IN_TIME_TEMPLATE = """<RestoreDBInstanceToPointInTimeResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
+  <RestoreDBInstanceToPointInTimeResult>
+  {{ database.to_xml() }}
+  </RestoreDBInstanceToPointInTimeResult>
+  <ResponseMetadata>
+    <RequestId>523e3218-afc7-11c3-90f5-f90431260ab4</RequestId>
+  </ResponseMetadata>
+</RestoreDBInstanceToPointInTimeResponse>"""
+
 CREATE_SNAPSHOT_TEMPLATE = """<CreateDBSnapshotResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <CreateDBSnapshotResult>
   {{ snapshot.to_xml() }}
@@ -1187,7 +1294,7 @@ REMOVE_TAGS_FROM_RESOURCE_TEMPLATE = """<RemoveTagsFromResourceResponse xmlns="h
 
 CREATE_DB_CLUSTER_TEMPLATE = """<CreateDBClusterResponse xmlns="http://rds.amazonaws.com/doc/2014-09-01/">
   <CreateDBClusterResult>
-  {{ cluster.to_xml() }}
+  {{ cluster.to_xml(initial=True) }}
   </CreateDBClusterResult>
   <ResponseMetadata>
     <RequestId>523e3218-afc7-11c3-90f5-f90431260ab4</RequestId>
@@ -1453,3 +1560,172 @@ PROMOTE_READ_REPLICA_DB_CLUSTER_TEMPLATE = """<PromoteReadReplicaDBClusterRespon
     <RequestId>7369556f-b70d-11c3-faca-6ba18376ea1b</RequestId>
   </ResponseMetadata>
 </PromoteReadReplicaDBClusterResponse>"""
+
+DESCRIBE_DB_SNAPSHOT_ATTRIBUTES_TEMPLATE = """<DescribeDBSnapshotAttributesResponse xmlns="http://rds.amazonaws.com/doc/2014-10-31/">
+  <DescribeDBSnapshotAttributesResult>
+    <DBSnapshotAttributesResult>
+      <DBSnapshotAttributes>
+        {%- for attribute in db_snapshot_attributes_result -%}
+          <DBSnapshotAttribute>
+            <AttributeName>{{ attribute["AttributeName"] }}</AttributeName>
+            <AttributeValues>
+              {%- for value in attribute["AttributeValues"] -%}
+                <AttributeValue>{{ value }}</AttributeValue>
+              {%- endfor -%}
+            </AttributeValues>
+          </DBSnapshotAttribute>
+        {%- endfor -%}
+      </DBSnapshotAttributes>
+      <DBSnapshotIdentifier>{{ db_snapshot_identifier }}</DBSnapshotIdentifier>
+    </DBSnapshotAttributesResult>
+  </DescribeDBSnapshotAttributesResult>
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334a</RequestId>
+  </ResponseMetadata>
+</DescribeDBSnapshotAttributesResponse>"""
+
+MODIFY_DB_SNAPSHOT_ATTRIBUTE_TEMPLATE = """<ModifyDBSnapshotAttributeResponse xmlns="http://rds.amazonaws.com/doc/2014-10-31/">
+  <ModifyDBSnapshotAttributeResult>
+    <DBSnapshotAttributesResult>
+      <DBSnapshotAttributes>
+        {%- for attribute in db_snapshot_attributes_result -%}
+          <DBSnapshotAttribute>
+            <AttributeName>{{ attribute["AttributeName"] }}</AttributeName>
+            <AttributeValues>
+              {%- for value in attribute["AttributeValues"] -%}
+                <AttributeValue>{{ value }}</AttributeValue>
+              {%- endfor -%}
+            </AttributeValues>
+          </DBSnapshotAttribute>
+        {%- endfor -%}
+      </DBSnapshotAttributes>
+      <DBSnapshotIdentifier>{{ db_snapshot_identifier }}</DBSnapshotIdentifier>
+    </DBSnapshotAttributesResult>
+  </ModifyDBSnapshotAttributeResult>
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334aEXAMPLE</RequestId>
+  </ResponseMetadata>
+</ModifyDBSnapshotAttributeResponse>"""
+
+MODIFY_DB_CLUSTER_SNAPSHOT_ATTRIBUTE_TEMPLATE = """<ModifyDBClusterSnapshotAttributeResponse xmlns="http://rds.amazonaws.com/doc/2014-10-31/">
+  <ModifyDBClusterSnapshotAttributeResult>
+    <DBClusterSnapshotAttributesResult>
+      <DBClusterSnapshotAttributes>
+        {%- for attribute in db_cluster_snapshot_attributes_result -%}
+          <DBClusterSnapshotAttribute>
+            <AttributeName>{{ attribute["AttributeName"] }}</AttributeName>
+            <AttributeValues>
+              {%- for value in attribute["AttributeValues"] -%}
+                <AttributeValue>{{ value }}</AttributeValue>
+              {%- endfor -%}
+            </AttributeValues>
+          </DBClusterSnapshotAttribute>
+        {%- endfor -%}
+      </DBClusterSnapshotAttributes>
+      <DBClusterSnapshotIdentifier>{{ db_cluster_snapshot_identifier }}</DBClusterSnapshotIdentifier>
+    </DBClusterSnapshotAttributesResult>
+  </ModifyDBClusterSnapshotAttributeResult>
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334a</RequestId>
+  </ResponseMetadata>
+</ModifyDBClusterSnapshotAttributeResponse>"""
+
+DESCRIBE_DB_CLUSTER_SNAPSHOT_ATTRIBUTES_TEMPLATE = """<DescribeDBClusterSnapshotAttributesResponse xmlns="http://rds.amazonaws.com/doc/2014-10-31/">
+  <DescribeDBClusterSnapshotAttributesResult>
+    <DBClusterSnapshotAttributesResult>
+      <DBClusterSnapshotAttributes>
+        {%- for attribute in db_cluster_snapshot_attributes_result -%}
+          <DBClusterSnapshotAttribute>
+            <AttributeName>{{ attribute["AttributeName"] }}</AttributeName>
+            <AttributeValues>
+              {%- for value in attribute["AttributeValues"] -%}
+                <AttributeValue>{{ value }}</AttributeValue>
+              {%- endfor -%}
+            </AttributeValues>
+          </DBClusterSnapshotAttribute> 
+        {%- endfor -%}
+      </DBClusterSnapshotAttributes>
+      <DBClusterSnapshotIdentifier>{{ db_cluster_snapshot_identifier }}</DBClusterSnapshotIdentifier>
+    </DBClusterSnapshotAttributesResult>
+  </DescribeDBClusterSnapshotAttributesResult>
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334a</RequestId>
+  </ResponseMetadata>
+</DescribeDBClusterSnapshotAttributesResponse>"""
+
+CREATE_DB_PROXY_TEMPLATE = """<CreateDBProxyResponse xmlns="http://rds.amazonaws.com/doc/2014-10-31/">
+  <CreateDBProxyResult>
+    <DBProxy>
+    {{ dbproxy.to_xml() }}
+    </DBProxy>
+  </CreateDBProxyResult>
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334aEXAMPLE</RequestId>
+  </ResponseMetadata>
+</CreateDBProxyResponse>"""
+
+DESCRIBE_DB_PROXIES_TEMPLATE = """<DescribeDBProxiesResponse xmlns="http://rds.amazonaws.com/doc/2014-10-31/">
+    <DescribeDBProxiesResult>
+        <DBProxies>
+          {% for dbproxy in dbproxies %}
+            <member>
+              {{ dbproxy.to_xml() }}
+            </member>
+          {% endfor %}
+        </DBProxies>
+    </DescribeDBProxiesResult>
+    <ResponseMetadata>
+        <RequestId>1549581b-12b7-11e3-895e-1334a</RequestId>
+    </ResponseMetadata>
+</DescribeDBProxiesResponse>
+"""
+
+CREATE_GLOBAL_CLUSTER_TEMPLATE = """<CreateGlobalClusterResponse xmlns="http://rds.amazonaws.com/doc/2014-10-31/">
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334aEXAMPLE</RequestId>
+  </ResponseMetadata>
+  <CreateGlobalClusterResult>
+  <GlobalCluster>
+    {{ cluster.to_xml() }}
+  </GlobalCluster>
+  </CreateGlobalClusterResult>
+</CreateGlobalClusterResponse>"""
+
+DELETE_GLOBAL_CLUSTER_TEMPLATE = """<DeleteGlobalClusterResponse xmlns="http://rds.amazonaws.com/doc/2014-10-31/">
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334aEXAMPLE</RequestId>
+  </ResponseMetadata>
+  <DeleteGlobalClusterResult>
+  <GlobalCluster>
+    {{ cluster.to_xml() }}
+  </GlobalCluster>
+  </DeleteGlobalClusterResult>
+</DeleteGlobalClusterResponse>"""
+
+DESCRIBE_GLOBAL_CLUSTERS_TEMPLATE = """<DescribeGlobalClustersResponse xmlns="http://rds.amazonaws.com/doc/2014-10-31/">
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334aEXAMPLE</RequestId>
+  </ResponseMetadata>
+  <DescribeGlobalClustersResult>
+    <GlobalClusters>
+{% for cluster in clusters %}
+    <GlobalClusterMember>
+        {{ cluster.to_xml() }}
+        </GlobalClusterMember>
+{% endfor %}
+    </GlobalClusters>
+  </DescribeGlobalClustersResult>
+</DescribeGlobalClustersResponse>"""
+
+REMOVE_FROM_GLOBAL_CLUSTER_TEMPLATE = """<RemoveFromGlobalClusterResponse xmlns="http://rds.amazonaws.com/doc/2014-10-31/">
+  <ResponseMetadata>
+    <RequestId>1549581b-12b7-11e3-895e-1334aEXAMPLE</RequestId>
+  </ResponseMetadata>
+  <RemoveFromGlobalClusterResult>
+  {% if cluster %}
+  <GlobalCluster>
+    {{ cluster.to_xml() }}
+  </GlobalCluster>
+  {% endif %}
+  </RemoveFromGlobalClusterResult>
+</RemoveFromGlobalClusterResponse>"""
